@@ -94,7 +94,7 @@ Node DTypeConstructor::getInstantiatedConstructor(TypeNode returnType) const
   Assert(isResolved());
   NodeManager* nm = NodeManager::currentNM();
   return nm->mkNode(
-      kind::APPLY_TYPE_ASCRIPTION,
+      Kind::APPLY_TYPE_ASCRIPTION,
       nm->mkConst(AscriptionType(getInstantiatedConstructorType(returnType))),
       d_constructor);
 }
@@ -109,7 +109,7 @@ void DTypeConstructor::setSygus(Node op)
 {
   Assert(!isResolved());
   d_sygusOp = op;
-  if (op.getKind() == SKOLEM)
+  if (op.getKind() == Kind::SKOLEM)
   {
     // check if stands for the "any constant" constructor
     NodeManager* nm = NodeManager::currentNM();
@@ -133,7 +133,8 @@ bool DTypeConstructor::isSygusIdFunc() const
 {
   Assert(isResolved());
   Assert(!d_sygusOp.isNull());
-  return (d_sygusOp.getKind() == LAMBDA && d_sygusOp[0].getNumChildren() == 1
+  return (d_sygusOp.getKind() == Kind::LAMBDA
+          && d_sygusOp[0].getNumChildren() == 1
           && d_sygusOp[0][0] == d_sygusOp[1]);
 }
 
@@ -465,7 +466,7 @@ Node DTypeConstructor::computeGroundTerm(TypeNode t,
     }
   }
 
-  Node groundTerm = nm->mkNode(APPLY_CONSTRUCTOR, groundTerms);
+  Node groundTerm = nm->mkNode(Kind::APPLY_CONSTRUCTOR, groundTerms);
   if (isParam)
   {
     Assert(DType::datatypeOf(d_constructor).isParametric());
@@ -473,10 +474,10 @@ Node DTypeConstructor::computeGroundTerm(TypeNode t,
     Trace("datatypes-init") << "ambiguous type for " << groundTerm
                             << ", ascribe to " << t << std::endl;
     groundTerms[0] = nm->mkNode(
-        APPLY_TYPE_ASCRIPTION,
+        Kind::APPLY_TYPE_ASCRIPTION,
         nm->mkConst(AscriptionType(getInstantiatedConstructorType(t))),
         groundTerms[0]);
-    groundTerm = nm->mkNode(APPLY_CONSTRUCTOR, groundTerms);
+    groundTerm = nm->mkNode(Kind::APPLY_CONSTRUCTOR, groundTerms);
   }
   Trace("datatypes-init") << "...return " << groundTerm << std::endl;
   Assert(!isValue || groundTerm.isConst()) << "Non-constant term " << groundTerm
@@ -669,7 +670,7 @@ TypeNode DTypeConstructor::doParametricSubstitution(
     children.push_back(
         doParametricSubstitution((*i), paramTypes, paramReplacements));
   }
-  if (range.getKind() == INSTANTIATED_SORT_TYPE)
+  if (range.getKind() == Kind::INSTANTIATED_SORT_TYPE)
   {
     // paramTypes contains a list of uninterpreted sort constructors.
     // paramReplacements contains a list of instantiated parametric datatypes.
