@@ -52,8 +52,10 @@ Smt2CmdParser::Smt2CmdParser(Smt2Lexer& lex,
   d_table["get-option"] = Token::GET_OPTION_TOK;
   d_table["get-proof"] = Token::GET_PROOF_TOK;
   d_table["get-timeout-core"] = Token::GET_TIMEOUT_CORE_TOK;
+  d_table["get-timeout-core-assuming"] = Token::GET_TIMEOUT_CORE_ASSUMING_TOK;
   d_table["get-unsat-assumptions"] = Token::GET_UNSAT_ASSUMPTIONS_TOK;
   d_table["get-unsat-core"] = Token::GET_UNSAT_CORE_TOK;
+  d_table["get-unsat-core-lemmas"] = Token::GET_UNSAT_CORE_LEMMAS_TOK;
   d_table["get-value"] = Token::GET_VALUE_TOK;
   d_table["pop"] = Token::POP_TOK;
   d_table["push"] = Token::PUSH_TOK;
@@ -675,6 +677,36 @@ std::unique_ptr<Cmd> Smt2CmdParser::parseNextCommand()
       cmd.reset(new GetTimeoutCoreCommand);
     }
     break;
+    case Token::GET_TIMEOUT_CORE_ASSUMING_TOK:
+    {
+      d_state.checkThatLogicIsSet();
+      // read optional assumptions
+      d_lex.eatToken(Token::LPAREN_TOK);
+      std::vector<Term> assumptions;
+      tok = d_lex.peekToken();
+      while (tok != Token::RPAREN_TOK)
+      {
+        d_state.clearLastNamedTerm();
+        Term t = d_tparser.parseTerm();
+        std::pair<Term, std::string> namedTerm = d_state.lastNamedTerm();
+        if (namedTerm.first == t)
+        {
+          d_state.getSymbolManager()->setExpressionName(
+              namedTerm.first, namedTerm.second, true);
+        }
+        assumptions.push_back(t);
+        tok = d_lex.peekToken();
+      }
+      if (assumptions.empty())
+      {
+        d_lex.parseError(
+            "Expected non-empty list of assumptions for "
+            "get-timeout-core-assuming");
+      }
+      d_lex.nextToken();
+      cmd.reset(new GetTimeoutCoreCommand(assumptions));
+    }
+    break;
     // (get-unsat-assumptions)
     case Token::GET_UNSAT_ASSUMPTIONS_TOK:
     {
@@ -689,6 +721,13 @@ std::unique_ptr<Cmd> Smt2CmdParser::parseNextCommand()
       cmd.reset(new GetUnsatCoreCommand);
     }
     break;
+    // (get-unsat-core-lemmas)
+    case Token::GET_UNSAT_CORE_LEMMAS_TOK:
+    {
+      d_state.checkThatLogicIsSet();
+      cmd.reset(new GetUnsatCoreLemmasCommand);
+    }
+    break;
     // (get-value (<term>+))
     case Token::GET_VALUE_TOK:
     {
@@ -770,10 +809,9 @@ std::unique_ptr<Cmd> Smt2CmdParser::parseNextCommand()
     {
       std::string key = d_tparser.parseKeyword();
       Term s = d_tparser.parseSymbolicExpr();
-      d_state.checkThatLogicIsSet();
-      // ":grammars" is defined in the SyGuS version 2.1 standard and is by
-      // default supported, all other features are not.
-      if (key != "grammars")
+      // ":grammars" and "fwd-decls" are defined in the SyGuS version 2.1
+      // standard and are supported by default, all other features are not.
+      if (key != "grammars" && key != "fwd-decls")
       {
         std::stringstream ss;
         ss << "SyGuS feature " << key << " not currently supported";
@@ -795,10 +833,17 @@ std::unique_ptr<Cmd> Smt2CmdParser::parseNextCommand()
     {
       SymManager* sm = d_state.getSymbolManager();
       std::string name = d_tparser.parseSymbol(CHECK_NONE, SYM_SORT);
-      // replace the logic with the forced logic, if applicable.
-      std::string lname = sm->isLogicForced() ? sm->getLogic() : name;
-      d_state.setLogic(lname);
-      cmd.reset(new SetBenchmarkLogicCommand(lname));
+      // If the logic was forced, we ignore all set-logic commands.
+      if (!sm->isLogicForced())
+      {
+        d_state.setLogic(name);
+        cmd.reset(new SetBenchmarkLogicCommand(name));
+      }
+      else
+      {
+        // otherwise ignore the command
+        cmd.reset(new EmptyCommand());
+      }
     }
     break;
     // (set-option <option>)
