@@ -105,7 +105,6 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
     // If in conflict, just return false
     Trace("non-clausal-simplify")
         << "conflict in non-clausal propagation" << std::endl;
-    assertionsToPreprocess->clear();
     assertionsToPreprocess->pushBackTrusted(conf);
     return PreprocessingPassResult::CONFLICT;
   }
@@ -122,12 +121,12 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
   // constant propagations
   std::shared_ptr<TrustSubstitutionMap> constantPropagations =
       std::make_shared<TrustSubstitutionMap>(
-          d_env, u, "NonClausalSimp::cprop", PfRule::PREPROCESS_LEMMA);
+          d_env, u, "NonClausalSimp::cprop", TrustId::PREPROCESS_LEMMA);
   SubstitutionMap& cps = constantPropagations->get();
   // new substitutions
   std::shared_ptr<TrustSubstitutionMap> newSubstitutions =
       std::make_shared<TrustSubstitutionMap>(
-          d_env, u, "NonClausalSimp::newSubs", PfRule::PREPROCESS_LEMMA);
+          d_env, u, "NonClausalSimp::newSubs", TrustId::PREPROCESS_LEMMA);
   SubstitutionMap& nss = newSubstitutions->get();
 
   size_t j = 0;
@@ -171,7 +170,6 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
         // If the learned literal simplifies to false, we're in conflict
         Trace("non-clausal-simplify")
             << "conflict with " << learned_literals[i].getNode() << std::endl;
-        assertionsToPreprocess->clear();
         Node n = nm->mkConst<bool>(false);
         assertionsToPreprocess->push_back(n, false, d_llpg.get());
         return PreprocessingPassResult::CONFLICT;
@@ -204,7 +202,6 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
         // If in conflict, we return false
         Trace("non-clausal-simplify")
             << "conflict while solving " << learnedLiteral << std::endl;
-        assertionsToPreprocess->clear();
         Node n = nm->mkConst<bool>(false);
         assertionsToPreprocess->push_back(n);
         return PreprocessingPassResult::CONFLICT;
@@ -212,7 +209,7 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
       default:
         TNode t;
         TNode c;
-        if (learnedLiteral.getKind() == kind::EQUAL
+        if (learnedLiteral.getKind() == Kind::EQUAL
             && (learnedLiteral[0].isConst() || learnedLiteral[1].isConst()))
         {
           // constant propagation
@@ -232,7 +229,7 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
           // From non-equalities, learn the Boolean equality. Notice that
           // the equality case above is strictly more powerful that this, since
           // e.g. (= t c) * { t -> c } also simplifies to true.
-          bool pol = learnedLiteral.getKind() != kind::NOT;
+          bool pol = learnedLiteral.getKind() != Kind::NOT;
           c = nm->mkConst(pol);
           t = pol ? learnedLiteral : learnedLiteral[0];
         }
@@ -331,6 +328,10 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
     s.insert(assertion);
     Trace("non-clausal-simplify")
         << "non-clausal preprocessed: " << assertion << std::endl;
+    if (assertionsToPreprocess->isInConflict())
+    {
+      return PreprocessingPassResult::CONFLICT;
+    }
   }
 
   // If necessary, add as assertions if needed (when incremental). This is
@@ -422,7 +423,8 @@ PreprocessingPassResult NonClausalSimp::applyInternal(
       }
       if (learnedLitsToConjoin.size() > 1)
       {
-        d_llra->addStep(newConj, PfRule::AND_INTRO, learnedLitsToConjoin, {});
+        d_llra->addStep(
+            newConj, ProofRule::AND_INTRO, learnedLitsToConjoin, {});
         pg = d_llra.get();
       }
       else
