@@ -25,6 +25,7 @@
 #include "proof/proof_checker.h"
 #include "proof/proof_node_algorithm.h"
 #include "proof/proof_node_manager.h"
+#include "proof/trust_id.h"
 #include "theory/builtin/proof_checker.h"
 
 namespace cvc5::internal {
@@ -32,7 +33,9 @@ namespace proof {
 
 DotPrinter::DotPrinter(Env& env)
     : EnvObj(env),
-      d_lbind(options().printer.dagThresh ? options().printer.dagThresh + 1 : 0),
+      d_lbind(
+          "let",
+          options().printer.dagThresh ? options().printer.dagThresh + 1 : 0),
       d_ruleID(0)
 {
   const std::string acronyms[5] = {"SAT", "CNF", "TL", "PP", "IN"};
@@ -185,7 +188,7 @@ void DotPrinter::print(std::ostream& out, const ProofNode* pn)
       }
       out << "\\\"let" << id << "\\\" : \\\"";
       std::ostringstream nStr;
-      nStr << d_lbind.convert(n, "let", false);
+      nStr << d_lbind.convert(n, false);
       std::string astring = nStr.str();
       // we double the scaping of quotes because "simple scape" is ambiguous
       // with the scape of the delimiter of the value in the key-value map
@@ -290,7 +293,7 @@ uint64_t DotPrinter::printInternal(
 
   d_ruleID++;
 
-  PfRule r = pn->getRule();
+  ProofRule r = pn->getRule();
 
   // Scopes trigger a traversal with a new local cache for proof nodes
   if (isSCOPE(r) && currentRuleID)
@@ -349,7 +352,7 @@ void DotPrinter::printProofNodeInfo(std::ostream& out, const ProofNode* pn)
   std::string astring = resultStr.str();
   out << sanitizeString(astring);
 
-  PfRule r = pn->getRule();
+  ProofRule r = pn->getRule();
   DotPrinter::ruleArguments(currentArguments, pn);
   astring = currentArguments.str();
   out << "|" << r << sanitizeString(astring) << "}\"";
@@ -363,7 +366,7 @@ void DotPrinter::printProofNodeInfo(std::ostream& out, const ProofNode* pn)
 ProofNodeClusterType DotPrinter::defineProofNodeType(const ProofNode* pn,
                                                      ProofNodeClusterType last)
 {
-  PfRule rule = pn->getRule();
+  ProofRule rule = pn->getRule();
   if (isSCOPE(rule))
   {
     d_scopesArgs.push_back(pn->getArguments());
@@ -397,7 +400,7 @@ ProofNodeClusterType DotPrinter::defineProofNodeType(const ProofNode* pn,
       return ProofNodeClusterType::CNF;
     }
     // If the first rule after a CNF is in the TL range
-    if (isTheoryLemma(rule))
+    if (isTheoryLemma(pn))
     {
       return ProofNodeClusterType::THEORY_LEMMA;
     }
@@ -444,48 +447,57 @@ inline bool DotPrinter::isInput(const ProofNode* pn)
   return true;
 }
 
-inline bool DotPrinter::isSat(const PfRule& rule)
+inline bool DotPrinter::isSat(const ProofRule& rule)
 {
-  return PfRule::CHAIN_RESOLUTION <= rule
-         && rule <= PfRule::MACRO_RESOLUTION_TRUST;
+  return ProofRule::CHAIN_RESOLUTION <= rule
+         && rule <= ProofRule::MACRO_RESOLUTION_TRUST;
 }
 
-inline bool DotPrinter::isCNF(const PfRule& rule)
+inline bool DotPrinter::isCNF(const ProofRule& rule)
 {
-  return PfRule::NOT_NOT_ELIM <= rule && rule <= PfRule::CNF_ITE_NEG3;
+  return ProofRule::NOT_NOT_ELIM <= rule && rule <= ProofRule::CNF_ITE_NEG3;
 }
 
-inline bool DotPrinter::isSCOPE(const PfRule& rule)
+inline bool DotPrinter::isSCOPE(const ProofRule& rule)
 {
-  return PfRule::SCOPE == rule;
+  return ProofRule::SCOPE == rule;
 }
 
-inline bool DotPrinter::isTheoryLemma(const PfRule& rule)
+inline bool DotPrinter::isTheoryLemma(const ProofNode* pn)
 {
-  return rule == PfRule::SCOPE || rule == PfRule::THEORY_LEMMA
-         || (PfRule::CNF_ITE_NEG3 < rule && rule < PfRule::LFSC_RULE);
+  ProofRule rule = pn->getRule();
+  if (rule == ProofRule::TRUST)
+  {
+    TrustId tid;
+    if (getTrustId(pn->getArguments()[0], tid))
+    {
+      return tid == TrustId::THEORY_LEMMA;
+    }
+  }
+  return rule == ProofRule::SCOPE
+         || (ProofRule::CNF_ITE_NEG3 < rule && rule < ProofRule::LFSC_RULE);
 }
 
-inline bool DotPrinter::isASSUME(const PfRule& rule)
+inline bool DotPrinter::isASSUME(const ProofRule& rule)
 {
-  return PfRule::ASSUME == rule;
+  return ProofRule::ASSUME == rule;
 }
 
 void DotPrinter::ruleArguments(std::ostringstream& currentArguments,
                                const ProofNode* pn)
 {
   const std::vector<Node>& args = pn->getArguments();
-  PfRule r = pn->getRule();
+  ProofRule r = pn->getRule();
   // don't process arguments of rules whose conclusion is in the arguments
-  if (!args.size() || r == PfRule::ASSUME || r == PfRule::REORDERING
-      || r == PfRule::REFL)
+  if (!args.size() || r == ProofRule::ASSUME || r == ProofRule::REORDERING
+      || r == ProofRule::REFL)
   {
     return;
   }
   currentArguments << " :args [ ";
 
   // if cong, special process
-  if (r == PfRule::CONG)
+  if (r == ProofRule::CONG)
   {
     AlwaysAssert(args.size() == 1 || args.size() == 2);
     // if two arguments, ignore first and print second
@@ -495,13 +507,13 @@ void DotPrinter::ruleArguments(std::ostringstream& currentArguments,
     }
     else
     {
-      Kind k;
+      Kind k = Kind::UNDEFINED_KIND;
       ProofRuleChecker::getKind(args[0], k);
       currentArguments << printer::smt2::Smt2Printer::smtKindString(k);
     }
   }
   // if th_rw, likewise
-  else if (r == PfRule::THEORY_REWRITE)
+  else if (r == ProofRule::TRUST_THEORY_REWRITE)
   {
     // print the second argument
     theory::TheoryId id;
