@@ -42,7 +42,7 @@ bool TheoryProofStepBuffer::applyEqIntro(Node src,
   bool added;
   Node expected = src.eqNode(tgt);
   Node res = tryStep(added,
-                     PfRule::MACRO_SR_EQ_INTRO,
+                     ProofRule::MACRO_SR_EQ_INTRO,
                      exp,
                      args,
                      useExpected ? expected : Node::null());
@@ -85,7 +85,7 @@ bool TheoryProofStepBuffer::applyPredTransform(Node src,
   children.insert(children.end(), exp.begin(), exp.end());
   args.push_back(tgt);
   addMethodIds(args, ids, ida, idr);
-  Node res = tryStep(PfRule::MACRO_SR_PRED_TRANSFORM,
+  Node res = tryStep(ProofRule::MACRO_SR_PRED_TRANSFORM,
                      children,
                      args,
                      useExpected ? tgt : Node::null());
@@ -109,8 +109,10 @@ bool TheoryProofStepBuffer::applyPredIntro(Node tgt,
   std::vector<Node> args;
   args.push_back(tgt);
   addMethodIds(args, ids, ida, idr);
-  Node res = tryStep(
-      PfRule::MACRO_SR_PRED_INTRO, exp, args, useExpected ? tgt : Node::null());
+  Node res = tryStep(ProofRule::MACRO_SR_PRED_INTRO,
+                     exp,
+                     args,
+                     useExpected ? tgt : Node::null());
   if (res.isNull())
   {
     return false;
@@ -131,7 +133,7 @@ Node TheoryProofStepBuffer::applyPredElim(Node src,
   std::vector<Node> args;
   addMethodIds(args, ids, ida, idr);
   bool added;
-  Node srcRew = tryStep(added, PfRule::MACRO_SR_PRED_ELIM, children, args);
+  Node srcRew = tryStep(added, ProofRule::MACRO_SR_PRED_ELIM, children, args);
   if (d_autoSym && added && CDProof::isSame(src, srcRew))
   {
     popStep();
@@ -141,7 +143,7 @@ Node TheoryProofStepBuffer::applyPredElim(Node src,
 
 Node TheoryProofStepBuffer::factorReorderElimDoubleNeg(Node n)
 {
-  if (n.getKind() != kind::OR)
+  if (n.getKind() != Kind::OR)
   {
     return elimDoubleNegLit(n);
   }
@@ -153,12 +155,12 @@ Node TheoryProofStepBuffer::factorReorderElimDoubleNeg(Node n)
   bool hasDoubleNeg = false;
   for (unsigned i = 0; i < children.size(); ++i)
   {
-    if (children[i].getKind() == kind::NOT
-        && children[i][0].getKind() == kind::NOT)
+    if (children[i].getKind() == Kind::NOT
+        && children[i][0].getKind() == Kind::NOT)
     {
       hasDoubleNeg = true;
       childrenEqs.push_back(children[i].eqNode(children[i][0][0]));
-      addStep(PfRule::MACRO_SR_PRED_INTRO,
+      addStep(ProofRule::MACRO_SR_PRED_INTRO,
               {},
               {childrenEqs.back()},
               childrenEqs.back());
@@ -168,13 +170,13 @@ Node TheoryProofStepBuffer::factorReorderElimDoubleNeg(Node n)
     else
     {
       childrenEqs.push_back(children[i].eqNode(children[i]));
-      addStep(PfRule::REFL, {}, {children[i]}, childrenEqs.back());
+      addStep(ProofRule::REFL, {}, {children[i]}, childrenEqs.back());
     }
   }
   if (hasDoubleNeg)
   {
     Node oldn = n;
-    n = nm->mkNode(kind::OR, children);
+    n = nm->mkNode(Kind::OR, children);
     // Create a congruence step to justify replacement of each doubly negated
     // literal. This is done to avoid having to use MACRO_SR_PRED_TRANSFORM
     // from the old clause to the new one, which, under the standard rewriter,
@@ -194,12 +196,12 @@ Node TheoryProofStepBuffer::factorReorderElimDoubleNeg(Node n)
     // pre-rewrite in the Boolean rewriter, will always hold under the
     // standard rewriter.
     Node congEq = oldn.eqNode(n);
-    addStep(PfRule::CONG,
+    addStep(ProofRule::CONG,
             childrenEqs,
-            {ProofRuleChecker::mkKindNode(kind::OR)},
+            {ProofRuleChecker::mkKindNode(Kind::OR)},
             congEq);
     // add an equality resolution step to derive normalize clause
-    addStep(PfRule::EQ_RESOLVE, {oldn, congEq}, {}, n);
+    addStep(ProofRule::EQ_RESOLVE, {oldn, congEq}, {}, n);
   }
   children.clear();
   // remove duplicates while keeping the order of children
@@ -217,12 +219,11 @@ Node TheoryProofStepBuffer::factorReorderElimDoubleNeg(Node n)
   // if factoring changed
   if (children.size() < size)
   {
-    Node factored = children.empty()
-                        ? nm->mkConst<bool>(false)
-                        : children.size() == 1 ? children[0]
-                                               : nm->mkNode(kind::OR, children);
+    Node factored = children.empty()       ? nm->mkConst<bool>(false)
+                    : children.size() == 1 ? children[0]
+                                           : nm->mkNode(Kind::OR, children);
     // don't overwrite what already has a proof step to avoid cycles
-    addStep(PfRule::FACTORING, {n}, {}, factored);
+    addStep(ProofRule::FACTORING, {n}, {}, factored);
     n = factored;
   }
   // nothing to order
@@ -232,12 +233,12 @@ Node TheoryProofStepBuffer::factorReorderElimDoubleNeg(Node n)
   }
   // order
   std::sort(children.begin(), children.end());
-  Node ordered = nm->mkNode(kind::OR, children);
+  Node ordered = nm->mkNode(Kind::OR, children);
   // if ordering changed
   if (ordered != n)
   {
     // don't overwrite what already has a proof step to avoid cycles
-    addStep(PfRule::REORDERING, {n}, {ordered}, ordered);
+    addStep(ProofRule::REORDERING, {n}, {ordered}, ordered);
   }
   return ordered;
 }
@@ -245,9 +246,9 @@ Node TheoryProofStepBuffer::factorReorderElimDoubleNeg(Node n)
 Node TheoryProofStepBuffer::elimDoubleNegLit(Node n)
 {
   // eliminate double neg
-  if (n.getKind() == kind::NOT && n[0].getKind() == kind::NOT)
+  if (n.getKind() == Kind::NOT && n[0].getKind() == Kind::NOT)
   {
-    addStep(PfRule::NOT_NOT_ELIM, {n}, {}, n[0][0]);
+    addStep(ProofRule::NOT_NOT_ELIM, {n}, {}, n[0][0]);
     return n[0][0];
   }
   return n;
