@@ -101,7 +101,10 @@ void TheoryProxy::presolve()
   d_stopSearch = false;
 }
 
-void TheoryProxy::postsolve() { d_theoryEngine->postsolve(); }
+void TheoryProxy::postsolve(SatValue result)
+{
+  d_theoryEngine->postsolve(result);
+}
 
 void TheoryProxy::notifyTopLevelSubstitution(const Node& lhs,
                                              const Node& rhs) const
@@ -167,10 +170,6 @@ void TheoryProxy::notifyAssertion(Node a, TNode skolem, bool isLemma)
   d_prr->addAssertion(a, skolem, isLemma);
 }
 
-void TheoryProxy::variableNotify(SatVariable var) {
-  notifySatLiteral(getNode(SatLiteral(var)));
-}
-
 void TheoryProxy::theoryCheck(theory::Theory::Effort effort) {
   Trace("theory-proxy") << "TheoryProxy: check " << effort << std::endl;
   d_activatedSkDefs = false;
@@ -262,7 +261,7 @@ void TheoryProxy::explainPropagation(SatLiteral l, SatClause& explanation) {
   Trace("prop-explain") << "explainPropagation() => " << theoryExplanation
                         << std::endl;
   explanation.push_back(l);
-  if (theoryExplanation.getKind() == kind::AND)
+  if (theoryExplanation.getKind() == Kind::AND)
   {
     for (const Node& n : theoryExplanation)
     {
@@ -311,10 +310,13 @@ SatLiteral TheoryProxy::getNextDecisionRequest(bool& requirePhase,
                                                bool& stopSearch)
 {
   Trace("theory-proxy") << "TheoryProxy: getNextDecisionRequest" << std::endl;
+  requirePhase = false;
+  stopSearch = false;
   SatLiteral res = undefSatLiteral;
   TNode n = d_theoryEngine->getNextDecisionRequest();
   if (!n.isNull())
   {
+    Trace("theory-proxy") << "... return next theory decision" << std::endl;
     requirePhase = true;
     res = d_cnfStream->getLiteral(n);
   }
@@ -325,7 +327,7 @@ SatLiteral TheoryProxy::getNextDecisionRequest(bool& requirePhase,
     requirePhase = false;
     if (d_stopSearch.get())
     {
-      Trace("theory-proxy") << "...stopped search, finish" << std::endl;
+      Trace("theory-proxy") << "...stop search, finished" << std::endl;
       stopSearch = true;
     }
     else
@@ -338,22 +340,22 @@ SatLiteral TheoryProxy::getNextDecisionRequest(bool& requirePhase,
       }
       else
       {
-        Trace("theory-proxy") << "...returned next decision" << std::endl;
+        Trace("theory-proxy") << "...return next decision" << std::endl;
       }
     }
   }
   return res;
 }
 
-bool TheoryProxy::theoryNeedCheck() const {
+bool TheoryProxy::theoryNeedCheck() const
+{
   if (d_stopSearch.get())
   {
     return false;
   }
   else if (d_activatedSkDefs)
   {
-    // a new skolem definition become active on the last call to theoryCheck,
-    // return true
+    // a new skolem definition became active on the last call to theoryCheck
     return true;
   }
   // otherwise ask the theory engine, which will return true if its output
@@ -402,17 +404,12 @@ void TheoryProxy::spendResource(Resource r)
   d_theoryEngine->spendResource(r);
 }
 
-bool TheoryProxy::isDecisionRelevant(SatVariable var) { return true; }
-
-bool TheoryProxy::isDecisionEngineDone() {
+bool TheoryProxy::isDecisionEngineDone()
+{
   return d_decisionEngine->isDone() || d_stopSearch.get();
 }
 
-SatValue TheoryProxy::getDecisionPolarity(SatVariable var) {
-  return SAT_VALUE_UNKNOWN;
-}
-
-CnfStream* TheoryProxy::getCnfStream() { return d_cnfStream; }
+CnfStream* TheoryProxy::getCnfStream() const { return d_cnfStream; }
 
 TrustNode TheoryProxy::preprocessLemma(
     TrustNode trn, std::vector<theory::SkolemLemma>& newLemmas)
@@ -452,10 +449,10 @@ void TheoryProxy::notifySatLiteral(Node n)
   d_prr->notifySatLiteral(n);
 }
 
-void TheoryProxy::notifyBacktrack(uint32_t nlevels)
+void TheoryProxy::notifyBacktrack()
 {
   // notify the preregistrar, which may trigger reregistrations
-  d_prr->notifyBacktrack(nlevels);
+  d_prr->notifyBacktrack();
 }
 
 std::vector<Node> TheoryProxy::getLearnedZeroLevelLiterals(
