@@ -17,6 +17,7 @@
 
 #include "expr/dtype.h"
 #include "expr/node_algorithm.h"
+#include "expr/node_converter.h"
 #include "printer/printer.h"
 
 using namespace cvc5::internal::kind;
@@ -24,9 +25,10 @@ using namespace cvc5::internal::kind;
 namespace cvc5::internal {
 namespace smt {
 
-void PrintBenchmark::printAssertions(std::ostream& out,
-                                     const std::vector<Node>& defs,
-                                     const std::vector<Node>& assertions)
+void PrintBenchmark::printDeclarationsFrom(std::ostream& outDecl,
+                                           std::ostream& outDef,
+                                           const std::vector<Node>& defs,
+                                           const std::vector<Node>& terms)
 {
   std::unordered_set<TypeNode> types;
   std::unordered_set<TNode> typeVisited;
@@ -34,7 +36,7 @@ void PrintBenchmark::printAssertions(std::ostream& out,
   {
     expr::getTypes(a, types, typeVisited);
   }
-  for (const Node& a : assertions)
+  for (const Node& a : terms)
   {
     Assert(!expr::hasFreeVar(a));
     expr::getTypes(a, types, typeVisited);
@@ -55,9 +57,15 @@ void PrintBenchmark::printAssertions(std::ostream& out,
       if ((ctn.isUninterpretedSort() && ctn.getNumChildren() == 0)
           || ctn.isUninterpretedSortConstructor())
       {
-        d_printer->toStreamCmdDeclareType(out, ctn);
+        TypeNode ctnp = ctn;
+        if (d_converter != nullptr)
+        {
+          ctnp = d_converter->convertType(ctnp);
+        }
+        d_printer->toStreamCmdDeclareType(outDecl, ctn);
+        outDecl << std::endl;
       }
-      else if (ctn.isDatatype())
+      else if (ctn.isDatatype() && !ctn.isTuple())
       {
         datatypeBlock.push_back(ctn);
       }
@@ -65,7 +73,8 @@ void PrintBenchmark::printAssertions(std::ostream& out,
     // print the mutually recursive datatype block if necessary
     if (!datatypeBlock.empty())
     {
-      d_printer->toStreamCmdDatatypeDeclaration(out, datatypeBlock);
+      d_printer->toStreamCmdDatatypeDeclaration(outDecl, datatypeBlock);
+      outDecl << std::endl;
     }
   }
 
@@ -78,10 +87,13 @@ void PrintBenchmark::printAssertions(std::ostream& out,
   // first, record all the defined symbols
   for (const Node& a : defs)
   {
-    bool isRec;
+    bool isRec = false;
     Node defSym;
     Node defBody;
-    decomposeDefinition(a, isRec, defSym, defBody);
+    if (!decomposeDefinition(a, isRec, defSym, defBody))
+    {
+      continue;
+    }
     if (!defSym.isNull())
     {
       Assert(defMap.find(defSym) == defMap.end());
@@ -103,14 +115,20 @@ void PrintBenchmark::printAssertions(std::ostream& out,
         s, recDefs, ordinaryDefs, syms, defMap, alreadyPrintedDef, visited);
     // print the declarations that are encountered for the first time in this
     // block
-    printDeclaredFuns(out, syms, alreadyPrintedDecl);
+    printDeclaredFuns(outDecl, syms, alreadyPrintedDecl);
     // print the ordinary definitions
     for (const Node& f : ordinaryDefs)
     {
       itd = defMap.find(f);
       Assert(itd != defMap.end());
       Assert(!itd->second.first);
-      d_printer->toStreamCmdDefineFunction(out, f, itd->second.second);
+      Node def = itd->second.second;
+      if (d_converter != nullptr)
+      {
+        def = d_converter->convert(def);
+      }
+      d_printer->toStreamCmdDefineFunction(outDef, f, def);
+      outDef << std::endl;
       // a definition is also a declaration
       alreadyPrintedDecl.insert(f);
     }
@@ -120,28 +138,46 @@ void PrintBenchmark::printAssertions(std::ostream& out,
       std::vector<Node> lambdas;
       for (const Node& f : recDefs)
       {
-        lambdas.push_back(defMap[f].second);
+        Node lam = defMap[f].second;
+        if (d_converter != nullptr)
+        {
+          lam = d_converter->convert(lam);
+        }
+        lambdas.push_back(lam);
         // a recursive definition is also a declaration
         alreadyPrintedDecl.insert(f);
       }
-      d_printer->toStreamCmdDefineFunctionRec(out, recDefs, lambdas);
+      d_printer->toStreamCmdDefineFunctionRec(outDef, recDefs, lambdas);
+      outDef << std::endl;
     }
   }
 
   // print the remaining declared symbols
   std::unordered_set<Node> syms;
-  for (const Node& a : assertions)
+  for (const Node& a : terms)
   {
     expr::getSymbols(a, syms, visited);
   }
-  printDeclaredFuns(out, syms, alreadyPrintedDecl);
-
+  printDeclaredFuns(outDecl, syms, alreadyPrintedDecl);
+}
+void PrintBenchmark::printAssertions(std::ostream& out,
+                                     const std::vector<Node>& defs,
+                                     const std::vector<Node>& assertions)
+{
+  printDeclarationsFrom(out, out, defs, assertions);
   // print the assertions
   for (const Node& a : assertions)
   {
-    d_printer->toStreamCmdAssert(out, a);
+    Node ap = a;
+    if (d_converter != nullptr)
+    {
+      ap = d_converter->convert(ap);
+    }
+    d_printer->toStreamCmdAssert(out, ap);
+    out << std::endl;
   }
 }
+
 void PrintBenchmark::printAssertions(std::ostream& out,
                                      const std::vector<Node>& assertions)
 {
@@ -164,6 +200,7 @@ void PrintBenchmark::printDeclaredFuns(std::ostream& out,
     if (alreadyPrinted.find(f) == alreadyPrinted.end())
     {
       d_printer->toStreamCmdDeclareFunction(out, f);
+      out << std::endl;
     }
   }
   alreadyPrinted.insert(funs.begin(), funs.end());
@@ -258,7 +295,7 @@ bool PrintBenchmark::decomposeDefinition(Node a,
                                          Node& sym,
                                          Node& body)
 {
-  if (a.getKind() == EQUAL && a[0].isVar())
+  if (a.getKind() == Kind::EQUAL && a[0].isVar())
   {
     // an ordinary define-fun
     isRecDef = false;
@@ -266,12 +303,12 @@ bool PrintBenchmark::decomposeDefinition(Node a,
     body = a[1];
     return true;
   }
-  else if (a.getKind() == FORALL && a[1].getKind() == EQUAL
-           && a[1][0].getKind() == APPLY_UF)
+  else if (a.getKind() == Kind::FORALL && a[1].getKind() == Kind::EQUAL
+           && a[1][0].getKind() == Kind::APPLY_UF)
   {
     isRecDef = true;
     sym = a[1][0].getOperator();
-    body = NodeManager::currentNM()->mkNode(LAMBDA, a[0], a[1][1]);
+    body = NodeManager::currentNM()->mkNode(Kind::LAMBDA, a[0], a[1][1]);
     return true;
   }
   else
@@ -287,8 +324,10 @@ void PrintBenchmark::printBenchmark(std::ostream& out,
                                     const std::vector<Node>& assertions)
 {
   d_printer->toStreamCmdSetBenchmarkLogic(out, logic);
+  out << std::endl;
   printAssertions(out, defs, assertions);
   d_printer->toStreamCmdCheckSat(out);
+  out << std::endl;
 }
 
 }  // namespace smt
