@@ -58,7 +58,7 @@ void ProofPostprocessCallback::initializeUpdate(ProofGenerator* pppg)
   d_pc = d_env.getProofNodeManager()->getChecker();
 }
 
-void ProofPostprocessCallback::setEliminateRule(PfRule rule)
+void ProofPostprocessCallback::setEliminateRule(ProofRule rule)
 {
   d_elimRules.insert(rule);
 }
@@ -72,7 +72,7 @@ bool ProofPostprocessCallback::shouldUpdate(std::shared_ptr<ProofNode> pn,
                                             const std::vector<Node>& fa,
                                             bool& continueUpdate)
 {
-  PfRule id = pn->getRule();
+  ProofRule id = pn->getRule();
   if (shouldExpand(id))
   {
     return true;
@@ -80,7 +80,7 @@ bool ProofPostprocessCallback::shouldUpdate(std::shared_ptr<ProofNode> pn,
   // other than elimination rules, we always update assumptions as long as
   // d_updateScopedAssumptions is true or they are *not* in scope, i.e., not in
   // fa
-  if (id != PfRule::ASSUME)
+  if (id != ProofRule::ASSUME)
   {
     return false;
   }
@@ -95,7 +95,7 @@ bool ProofPostprocessCallback::shouldUpdate(std::shared_ptr<ProofNode> pn,
 }
 
 bool ProofPostprocessCallback::update(Node res,
-                                      PfRule id,
+                                      ProofRule id,
                                       const std::vector<Node>& children,
                                       const std::vector<Node>& args,
                                       CDProof* cdp,
@@ -104,7 +104,7 @@ bool ProofPostprocessCallback::update(Node res,
   Trace("smt-proof-pp-debug") << "- Post process " << id << " " << children
                               << " / " << args << std::endl;
 
-  if (id == PfRule::ASSUME)
+  if (id == ProofRule::ASSUME)
   {
     // we cache based on the assumption node, not the proof node, since there
     // may be multiple occurrences of the same node.
@@ -142,7 +142,7 @@ bool ProofPostprocessCallback::update(Node res,
       }
       d_assumpToProof[f] = pfn;
     }
-    if (pfn == nullptr || pfn->getRule() == PfRule::ASSUME)
+    if (pfn == nullptr || pfn->getRule() == ProofRule::ASSUME)
     {
       Trace("smt-proof-pp-debug") << "...do not add proof" << std::endl;
       // no update
@@ -159,7 +159,7 @@ bool ProofPostprocessCallback::update(Node res,
 }
 
 bool ProofPostprocessCallback::updateInternal(Node res,
-                                              PfRule id,
+                                              ProofRule id,
                                               const std::vector<Node>& children,
                                               const std::vector<Node>& args,
                                               CDProof* cdp)
@@ -168,7 +168,7 @@ bool ProofPostprocessCallback::updateInternal(Node res,
   return update(res, id, children, args, cdp, continueUpdate);
 }
 
-bool ProofPostprocessCallback::shouldExpand(PfRule id) const
+bool ProofPostprocessCallback::shouldExpand(ProofRule id) const
 {
   if (d_elimRules.find(id) != d_elimRules.end())
   {
@@ -181,7 +181,7 @@ bool ProofPostprocessCallback::shouldExpand(PfRule id) const
   return false;
 }
 
-Node ProofPostprocessCallback::expandMacros(PfRule id,
+Node ProofPostprocessCallback::expandMacros(ProofRule id,
                                             const std::vector<Node>& children,
                                             const std::vector<Node>& args,
                                             CDProof* cdp,
@@ -194,7 +194,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
   }
   Trace("smt-proof-pp-debug") << "Expand macro " << id << std::endl;
   // macro elimination
-  if (id == PfRule::MACRO_SR_EQ_INTRO)
+  if (id == ProofRule::MACRO_SR_EQ_INTRO)
   {
     // (TRANS
     //   (SUBS <children> :args args[0:1])
@@ -231,10 +231,10 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       {
         Node eq = t.eqNode(ts);
         // apply SUBS proof rule if necessary
-        if (!updateInternal(eq, PfRule::SUBS, children, sargs, cdp))
+        if (!updateInternal(eq, ProofRule::SUBS, children, sargs, cdp))
         {
           // if we specified that we did not want to eliminate, add as step
-          cdp->addStep(eq, PfRule::SUBS, children, sargs);
+          cdp->addStep(eq, ProofRule::SUBS, children, sargs);
         }
         tchildren.push_back(eq);
       }
@@ -262,23 +262,23 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     {
       Node eq = ts.eqNode(tr);
       // apply REWRITE proof rule
-      if (!updateInternal(eq, PfRule::REWRITE, {}, rargs, cdp))
+      if (!updateInternal(eq, ProofRule::MACRO_REWRITE, {}, rargs, cdp))
       {
         // if not elimianted, add as step
-        cdp->addStep(eq, PfRule::REWRITE, {}, rargs);
+        cdp->addStep(eq, ProofRule::MACRO_REWRITE, {}, rargs);
       }
       tchildren.push_back(eq);
     }
     if (t == tr)
     {
       // typically not necessary, but done to be robust
-      cdp->addStep(t.eqNode(tr), PfRule::REFL, {}, {t});
+      cdp->addStep(t.eqNode(tr), ProofRule::REFL, {}, {t});
       return t.eqNode(tr);
     }
     // must add TRANS if two step
     return addProofForTrans(tchildren, cdp);
   }
-  else if (id == PfRule::MACRO_SR_PRED_INTRO)
+  else if (id == ProofRule::MACRO_SR_PRED_INTRO)
   {
     std::vector<Node> tchildren;
     std::vector<Node> sargs = args;
@@ -297,11 +297,12 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     // We call the expandMacros method on MACRO_SR_EQ_INTRO, where notice
     // that this rule application is immediately expanded in the recursive
     // call and not added to the proof.
-    Node conc = expandMacros(PfRule::MACRO_SR_EQ_INTRO, children, sargs, cdp);
+    Node conc =
+        expandMacros(ProofRule::MACRO_SR_EQ_INTRO, children, sargs, cdp);
     Trace("smt-proof-pp-debug")
         << "...pred intro conclusion is " << conc << std::endl;
     Assert(!conc.isNull());
-    Assert(conc.getKind() == EQUAL);
+    Assert(conc.getKind() == Kind::EQUAL);
     Assert(conc[0] == args[0]);
     tchildren.push_back(conc);
     if (reqWitness)
@@ -313,21 +314,22 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
         // toWitness(apply_SR(t)) = apply_SR(toWitness(apply_SR(t)))
         // rewrite again, don't need substitution. Also we always use the
         // default rewriter, due to the definition of MACRO_SR_PRED_INTRO.
-        Node weqr = expandMacros(PfRule::MACRO_SR_EQ_INTRO, {}, {weq[1]}, cdp);
+        Node weqr =
+            expandMacros(ProofRule::MACRO_SR_EQ_INTRO, {}, {weq[1]}, cdp);
         addToTransChildren(weqr, tchildren);
       }
     }
     // apply transitivity if necessary
     Node eq = addProofForTrans(tchildren, cdp);
     Assert(!eq.isNull());
-    Assert(eq.getKind() == EQUAL);
+    Assert(eq.getKind() == Kind::EQUAL);
     Assert(eq[0] == args[0]);
     Assert(eq[1] == d_true);
 
-    cdp->addStep(eq[0], PfRule::TRUE_ELIM, {eq}, {});
+    cdp->addStep(eq[0], ProofRule::TRUE_ELIM, {eq}, {});
     return eq[0];
   }
-  else if (id == PfRule::MACRO_SR_PRED_ELIM)
+  else if (id == ProofRule::MACRO_SR_PRED_ELIM)
   {
     // (EQ_RESOLVE
     //   children[0]
@@ -336,15 +338,16 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     std::vector<Node> srargs;
     srargs.push_back(children[0]);
     srargs.insert(srargs.end(), args.begin(), args.end());
-    Node conc = expandMacros(PfRule::MACRO_SR_EQ_INTRO, schildren, srargs, cdp);
+    Node conc =
+        expandMacros(ProofRule::MACRO_SR_EQ_INTRO, schildren, srargs, cdp);
     Assert(!conc.isNull());
-    Assert(conc.getKind() == EQUAL);
+    Assert(conc.getKind() == Kind::EQUAL);
     Assert(conc[0] == children[0]);
     // apply equality resolve
-    cdp->addStep(conc[1], PfRule::EQ_RESOLVE, {children[0], conc}, {});
+    cdp->addStep(conc[1], ProofRule::EQ_RESOLVE, {children[0], conc}, {});
     return conc[1];
   }
-  else if (id == PfRule::MACRO_SR_PRED_TRANSFORM)
+  else if (id == ProofRule::MACRO_SR_PRED_TRANSFORM)
   {
     // (EQ_RESOLVE
     //   children[0]
@@ -380,10 +383,11 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       // first rewrite children[0], then args[0]
       sargs[0] = r == 0 ? children[0] : args[0];
       // t = apply_SR(t)
-      Node eq = expandMacros(PfRule::MACRO_SR_EQ_INTRO, schildren, sargs, cdp);
+      Node eq =
+          expandMacros(ProofRule::MACRO_SR_EQ_INTRO, schildren, sargs, cdp);
       Trace("smt-proof-pp-debug")
           << "transform subs_rewrite (" << r << "): " << eq << std::endl;
-      Assert(!eq.isNull() && eq.getKind() == EQUAL && eq[0] == sargs[0]);
+      Assert(!eq.isNull() && eq.getKind() == Kind::EQUAL && eq[0] == sargs[0]);
       addToTransChildren(eq, tchildrenr);
       // apply_SR(t) = toWitness(apply_SR(t))
       if (reqWitness)
@@ -397,7 +401,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
           // rewrite again, don't need substitution. Also, we always use the
           // default rewriter, due to the definition of MACRO_SR_PRED_TRANSFORM.
           Node weqr =
-              expandMacros(PfRule::MACRO_SR_EQ_INTRO, {}, {weq[1]}, cdp);
+              expandMacros(ProofRule::MACRO_SR_EQ_INTRO, {}, {weq[1]}, cdp);
           Trace("smt-proof-pp-debug") << "transform rewrite_witness (" << r
                                       << "): " << weqr << std::endl;
           addToTransChildren(weqr, tchildrenr);
@@ -430,17 +434,17 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     // apply transitivity if necessary
     Node eq = addProofForTrans(tchildren, cdp);
 
-    cdp->addStep(eq[1], PfRule::EQ_RESOLVE, {children[0], eq}, {});
+    cdp->addStep(eq[1], ProofRule::EQ_RESOLVE, {children[0], eq}, {});
     return args[0];
   }
-  else if (id == PfRule::MACRO_RESOLUTION
-           || id == PfRule::MACRO_RESOLUTION_TRUST)
+  else if (id == ProofRule::MACRO_RESOLUTION
+           || id == ProofRule::MACRO_RESOLUTION_TRUST)
   {
     ProofNodeManager* pnm = d_env.getProofNodeManager();
     // first generate the naive chain_resolution
     std::vector<Node> chainResArgs{args.begin() + 1, args.end()};
     Node chainConclusion = d_pc->checkDebug(
-        PfRule::CHAIN_RESOLUTION, children, chainResArgs, Node::null(), "");
+        ProofRule::CHAIN_RESOLUTION, children, chainResArgs, Node::null(), "");
     Trace("smt-proof-pp-debug") << "Original conclusion: " << args[0] << "\n";
     Trace("smt-proof-pp-debug")
         << "chainRes conclusion: " << chainConclusion << "\n";
@@ -463,13 +467,13 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       Trace("smt-proof-pp-debug") << "..same conclusion, DONE.\n";
       Trace("crowding-lits") << "..same conclusion, DONE.\n";
       cdp->addStep(
-          chainConclusion, PfRule::CHAIN_RESOLUTION, children, chainResArgs);
+          chainConclusion, ProofRule::CHAIN_RESOLUTION, children, chainResArgs);
       return chainConclusion;
     }
     size_t initProofSize = cdp->getNumProofNodes();
     NodeManager* nm = NodeManager::currentNM();
     // If we got here, then chainConclusion is NECESSARILY an OR node
-    Assert(chainConclusion.getKind() == kind::OR);
+    Assert(chainConclusion.getKind() == Kind::OR);
     // get the literals in the chain conclusion
     std::vector<Node> chainConclusionLits{chainConclusion.begin(),
                                           chainConclusion.end()};
@@ -503,7 +507,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     }
     else
     {
-      Assert(args[0].getKind() == kind::OR);
+      Assert(args[0].getKind() == Kind::OR);
       conclusionLits.insert(
           conclusionLits.end(), args[0].begin(), args[0].end());
     }
@@ -539,7 +543,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       }
       else
       {
-        Assert(chainConclusion.getKind() == kind::OR);
+        Assert(chainConclusion.getKind() == Kind::OR);
         chainConclusionLits.insert(chainConclusionLits.end(),
                                    chainConclusion.begin(),
                                    chainConclusion.end());
@@ -549,7 +553,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     {
       Trace("smt-proof-pp-debug") << "..add chainRes step directly.\n";
       cdp->addStep(
-          chainConclusion, PfRule::CHAIN_RESOLUTION, children, chainResArgs);
+          chainConclusion, ProofRule::CHAIN_RESOLUTION, children, chainResArgs);
     }
     Trace("smt-proof-pp-debug")
         << "Conclusion after chain_res/elimCrowd: " << chainConclusion << "\n";
@@ -574,27 +578,26 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
         factoredLits.push_back(n[i]);
         clauseSet.insert(n[i]);
       }
-      Node factored = factoredLits.empty()
-                          ? nm->mkConst(false)
-                          : factoredLits.size() == 1
-                                ? factoredLits[0]
-                                : nm->mkNode(kind::OR, factoredLits);
-      cdp->addStep(factored, PfRule::FACTORING, {n}, {});
+      Node factored = factoredLits.empty() ? nm->mkConst(false)
+                      : factoredLits.size() == 1
+                          ? factoredLits[0]
+                          : nm->mkNode(Kind::OR, factoredLits);
+      cdp->addStep(factored, ProofRule::FACTORING, {n}, {});
       n = factored;
     }
     // either same node or n as a clause
-    Assert(n == args[0] || n.getKind() == kind::OR);
+    Assert(n == args[0] || n.getKind() == Kind::OR);
     // reordering
     if (n != args[0])
     {
       Trace("smt-proof-pp-debug") << "..add reordering step.\n";
-      cdp->addStep(args[0], PfRule::REORDERING, {n}, {args[0]});
+      cdp->addStep(args[0], ProofRule::REORDERING, {n}, {args[0]});
     }
     Trace("crowding-lits") << "Number of added proof nodes: "
                            << cdp->getNumProofNodes() - initProofSize << "\n";
     return args[0];
   }
-  else if (id == PfRule::SUBS)
+  else if (id == ProofRule::SUBS)
   {
     NodeManager* nm = NodeManager::currentNM();
     // Notice that a naive way to reconstruct SUBS is to do a term conversion
@@ -637,14 +640,14 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       builtin::BuiltinProofRuleChecker::getSubstitutionFor(
           children[i], vsList, ssList, fromList, ids);
       // ensure proofs for each formula in fromList
-      if (children[i].getKind() == AND && ids == MethodId::SB_DEFAULT)
+      if (children[i].getKind() == Kind::AND && ids == MethodId::SB_DEFAULT)
       {
         for (size_t j = 0, nchildi = children[i].getNumChildren(); j < nchildi;
              j++)
         {
           Node nodej = nm->mkConstInt(Rational(j));
           cdp->addStep(
-              children[i][j], PfRule::AND_ELIM, {children[i]}, {nodej});
+              children[i][j], ProofRule::AND_ELIM, {children[i]}, {nodej});
         }
       }
     }
@@ -700,7 +703,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
           // ensure we have a proof of var = subs
           Node veqs = addProofForSubsStep(var, subs, childFrom, pf.get());
           // transitivity
-          pf->addStep(var.eqNode(ss), PfRule::TRANS, {veqs, seqss}, {});
+          pf->addStep(var.eqNode(ss), ProofRule::TRANS, {veqs, seqss}, {});
           // add to the substitution
           vvec.push_back(var);
           svec.push_back(ss);
@@ -765,12 +768,12 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
             // ensure the proof for the substitution exists
             addProofForSubsStep(var, subs, fromList[ii], cdp);
             // do the single step SUBS on curr with the default arguments
-            cdp->addStep(eqo, PfRule::SUBS, {var.eqNode(subs)}, {curr});
+            cdp->addStep(eqo, ProofRule::SUBS, {var.eqNode(subs)}, {curr});
             curr = next;
           }
         }
         Assert(curr == ts);
-        cdp->addStep(eqq, PfRule::TRANS, transChildren, {});
+        cdp->addStep(eqq, ProofRule::TRANS, transChildren, {});
       }
       else
       {
@@ -779,7 +782,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
             << eq << std::endl
             << eqq << std::endl
             << "from " << children << " applied to " << t << std::endl;
-        cdp->addStep(eqq, PfRule::TRUST_SUBS, children, {eqq});
+        cdp->addTrustedStep(eqq, TrustId::SUBS_NO_ELABORATE, children, {});
       }
     }
     else
@@ -788,7 +791,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     }
     return eqq;
   }
-  else if (id == PfRule::REWRITE)
+  else if (id == ProofRule::MACRO_REWRITE)
   {
     // get the kind of rewrite
     MethodId idr = MethodId::RW_REWRITE;
@@ -814,15 +817,16 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
         // did not have a proof of rewriting, probably isExtEq is true
         if (isExtEq)
         {
-          // update to THEORY_REWRITE with idr
+          // update to TRUST_THEORY_REWRITE with idr
           Assert(args.size() >= 1);
           Node tid = builtin::BuiltinProofRuleChecker::mkTheoryIdNode(theoryId);
-          cdp->addStep(eq, PfRule::THEORY_REWRITE, {}, {eq, tid, args[1]});
+          cdp->addStep(
+              eq, ProofRule::TRUST_THEORY_REWRITE, {}, {eq, tid, args[1]});
         }
         else
         {
           // this should never be applied
-          cdp->addStep(eq, PfRule::TRUST_REWRITE, {}, {eq});
+          cdp->addTrustedStep(eq, TrustId::REWRITE_NO_ELABORATE, {}, {});
         }
       }
       else
@@ -837,7 +841,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     else if (idr == MethodId::RW_EVALUATE)
     {
       // change to evaluate, which is never eliminated
-      cdp->addStep(eq, PfRule::EVALUATE, {}, {args[0]});
+      cdp->addStep(eq, ProofRule::EVALUATE, {}, {args[0]});
     }
     else
     {
@@ -848,7 +852,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       // rewriter
       for (size_t i = 0; i < 2; i++)
       {
-        if (i == 1 && retCurr.getKind() != EQUAL)
+        if (i == 1 && retCurr.getKind() != Kind::EQUAL)
         {
           break;
         }
@@ -860,7 +864,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
           // will expand this as a default rewrite if needed
           Node eqd = retCurr.eqNode(retDef);
           Node mid = mkMethodId(midi);
-          cdp->addStep(eqd, PfRule::REWRITE, {}, {retCurr, mid});
+          cdp->addStep(eqd, ProofRule::MACRO_REWRITE, {}, {retCurr, mid});
           transEq.push_back(eqd);
         }
         retCurr = retDef;
@@ -882,7 +886,8 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
         // in this case, must be a non-standard rewrite kind
         Assert(args.size() >= 2);
         targs.push_back(args[1]);
-        Node eqpp = expandMacros(PfRule::THEORY_REWRITE, {}, targs, cdp);
+        Node eqpp =
+            expandMacros(ProofRule::TRUST_THEORY_REWRITE, {}, targs, cdp);
         transEq.push_back(eqp);
         if (eqpp.isNull())
         {
@@ -893,17 +898,17 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       if (transEq.size() > 1)
       {
         // put together with transitivity
-        cdp->addStep(eq, PfRule::TRANS, transEq, {});
+        cdp->addStep(eq, ProofRule::TRANS, transEq, {});
       }
     }
     if (args[0] == ret)
     {
       // should not be necessary typically
-      cdp->addStep(eq, PfRule::REFL, {}, {args[0]});
+      cdp->addStep(eq, ProofRule::REFL, {}, {args[0]});
     }
     return eq;
   }
-  else if (id == PfRule::MACRO_ARITH_SCALE_SUM_UB)
+  else if (id == ProofRule::MACRO_ARITH_SCALE_SUM_UB)
   {
     Trace("macro::arith") << "Expand MACRO_ARITH_SCALE_SUM_UB" << std::endl;
     if (TraceIsOn("macro::arith"))
@@ -925,37 +930,38 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       TNode child = children[i];
       TNode scalar = args[i];
       bool isPos = scalar.getConst<Rational>() > 0;
-      Node scalarCmp =
-          nm->mkNode(isPos ? GT : LT, scalar, nm->mkConstInt(Rational(0)));
+      Node scalarCmp = nm->mkNode(
+          isPos ? Kind::GT : Kind::LT, scalar, nm->mkConstInt(Rational(0)));
       // (= scalarCmp true)
-      Node scalarCmpOrTrue = steps.tryStep(PfRule::EVALUATE, {}, {scalarCmp});
+      Node scalarCmpOrTrue =
+          steps.tryStep(ProofRule::EVALUATE, {}, {scalarCmp});
       Assert(!scalarCmpOrTrue.isNull());
       // scalarCmp
-      steps.addStep(PfRule::TRUE_ELIM, {scalarCmpOrTrue}, {}, scalarCmp);
+      steps.addStep(ProofRule::TRUE_ELIM, {scalarCmpOrTrue}, {}, scalarCmp);
       // (and scalarCmp relation)
       Node scalarCmpAndRel =
-          steps.tryStep(PfRule::AND_INTRO, {scalarCmp, child}, {});
+          steps.tryStep(ProofRule::AND_INTRO, {scalarCmp, child}, {});
       Assert(!scalarCmpAndRel.isNull());
       // (=> (and scalarCmp relation) scaled)
-      Node impl =
-          steps.tryStep(isPos ? PfRule::ARITH_MULT_POS : PfRule::ARITH_MULT_NEG,
-                        {},
-                        {scalar, child});
+      Node impl = steps.tryStep(
+          isPos ? ProofRule::ARITH_MULT_POS : ProofRule::ARITH_MULT_NEG,
+          {},
+          {scalar, child});
       Assert(!impl.isNull());
       // scaled
       Node scaled =
-          steps.tryStep(PfRule::MODUS_PONENS, {scalarCmpAndRel, impl}, {});
+          steps.tryStep(ProofRule::MODUS_PONENS, {scalarCmpAndRel, impl}, {});
       Assert(!scaled.isNull());
       scaledRels.emplace_back(scaled);
     }
 
-    Node sumBounds = steps.tryStep(PfRule::ARITH_SUM_UB, scaledRels, {});
+    Node sumBounds = steps.tryStep(ProofRule::ARITH_SUM_UB, scaledRels, {});
     cdp->addSteps(steps);
     Trace("macro::arith") << "Expansion done. Proved: " << sumBounds
                           << std::endl;
     return sumBounds;
   }
-  else if (id == PfRule::STRING_INFERENCE)
+  else if (id == ProofRule::MACRO_STRING_INFERENCE)
   {
     // get the arguments
     Node conc;
@@ -972,11 +978,11 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       }
     }
   }
-  else if (id == PfRule::BV_BITBLAST)
+  else if (id == ProofRule::MACRO_BV_BITBLAST)
   {
     bv::BBProof bb(d_env, nullptr, true);
     Node eq = args[0];
-    Assert(eq.getKind() == EQUAL);
+    Assert(eq.getKind() == Kind::EQUAL);
     bb.bbAtom(eq[0]);
     Node bbAtom = bb.getStoredBBAtom(eq[0]);
     bb.getProofGenerator()->addProofTo(eq[0].eqNode(bbAtom), cdp);
@@ -991,7 +997,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     }
     bool reqTrueElim = false;
     // if not an equality, make (= res true).
-    if (res.getKind() != EQUAL)
+    if (res.getKind() != Kind::EQUAL)
     {
       res = res.eqNode(d_true);
       reqTrueElim = true;
@@ -999,7 +1005,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     TheoryId tid = THEORY_LAST;
     MethodId mid = MethodId::RW_REWRITE;
     // if theory rewrite, get diagnostic information
-    if (id == PfRule::THEORY_REWRITE)
+    if (id == ProofRule::TRUST_THEORY_REWRITE)
     {
       builtin::BuiltinProofRuleChecker::getTheoryId(args[1], tid);
       getMethodId(args[2], mid);
@@ -1012,7 +1018,7 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
       // If we made (= res true) above, conclude the original res.
       if (reqTrueElim)
       {
-        cdp->addStep(res[0], PfRule::TRUE_ELIM, {res}, {});
+        cdp->addStep(res[0], ProofRule::TRUE_ELIM, {res}, {});
         res = res[0];
       }
       // if successful, we update the proof
@@ -1020,9 +1026,6 @@ Node ProofPostprocessCallback::expandMacros(PfRule id,
     }
     // otherwise no update
   }
-
-  // TRUST, PREPROCESS, THEORY_LEMMA, THEORY_PREPROCESS?
-
   return Node::null();
 }
 
@@ -1033,7 +1036,7 @@ Node ProofPostprocessCallback::addProofForWitnessForm(Node t, CDProof* cdp)
   if (t == tw)
   {
     // not necessary, add REFL step
-    cdp->addStep(eq, PfRule::REFL, {}, {t});
+    cdp->addStep(eq, ProofRule::REFL, {}, {t});
     return eq;
   }
   std::shared_ptr<ProofNode> pn = d_wfpm.getProofFor(eq);
@@ -1060,7 +1063,7 @@ Node ProofPostprocessCallback::addProofForTrans(
     Node lhs = tchildren[0][0];
     Node rhs = tchildren[tsize - 1][1];
     Node eq = lhs.eqNode(rhs);
-    cdp->addStep(eq, PfRule::TRANS, tchildren, {});
+    cdp->addStep(eq, ProofRule::TRANS, tchildren, {});
     return eq;
   }
   else if (tsize == 1)
@@ -1083,7 +1086,7 @@ Node ProofPostprocessCallback::addProofForSubsStep(Node var,
     Assert(subs.isConst());
     cdp->addStep(
         veqs,
-        subs.getConst<bool>() ? PfRule::TRUE_INTRO : PfRule::FALSE_INTRO,
+        subs.getConst<bool>() ? ProofRule::TRUE_INTRO : ProofRule::FALSE_INTRO,
         {assump},
         {});
   }
@@ -1095,14 +1098,14 @@ bool ProofPostprocessCallback::addToTransChildren(Node eq,
                                                   bool isSymm)
 {
   Assert(!eq.isNull());
-  Assert(eq.getKind() == kind::EQUAL);
+  Assert(eq.getKind() == Kind::EQUAL);
   if (eq[0] == eq[1])
   {
     return false;
   }
   Node equ = isSymm ? eq[1].eqNode(eq[0]) : eq;
   Assert(tchildren.empty()
-         || (tchildren[tchildren.size() - 1].getKind() == kind::EQUAL
+         || (tchildren[tchildren.size() - 1].getKind() == Kind::EQUAL
              && tchildren[tchildren.size() - 1][1] == equ[0]));
   tchildren.push_back(equ);
   return true;
@@ -1144,7 +1147,7 @@ void ProofPostprocess::process(std::shared_ptr<ProofNode> pf,
   }
 }
 
-void ProofPostprocess::setEliminateRule(PfRule rule)
+void ProofPostprocess::setEliminateRule(ProofRule rule)
 {
   d_cb.setEliminateRule(rule);
 }
@@ -1154,5 +1157,11 @@ void ProofPostprocess::setEliminateAllTrustedRules()
   d_cb.setEliminateAllTrustedRules();
 }
 
+void ProofPostprocess::setAssertions(const std::vector<Node>& assertions,
+                                     bool doDebug)
+{
+  d_updater.setFreeAssumptions(assertions, doDebug);
+}
+
 }  // namespace smt
 }  // namespace cvc5::internal
